@@ -10,28 +10,6 @@ our @EXPORT = qw( EXCEPTION_CLASS FALSE LANG NUL TRUE );
 
 my $Exception_Class = 'Web::ComposableRequest::Exception';
 
-no warnings 'redefine';
-
-my $role_suffix = 'A000';
-
-*Role::Tiny::_composite_name = sub {
-  my ($me, $superclass, @roles) = @_;
-
-  my $new_name = join(
-    '__WITH__', $superclass, my $compose_name = join( '__AND__', @roles )
-  );
-
-  if (length($new_name) > 240) {
-    $new_name = $Role::Tiny::COMPOSED{abbrev}{$new_name} ||= do {
-      my $abbrev = substr $new_name, 0, 238 - length $role_suffix;
-      $abbrev =~ s/(?<!:):$//;
-      $abbrev.'__'.$role_suffix++;
-    };
-  }
-
-  return wantarray ? ($new_name, $compose_name) : $new_name;
-};
-
 sub FALSE () { 0    }
 sub LANG  () { 'en' }
 sub NUL   () { q()  }
